@@ -120,7 +120,7 @@ public class WebserviceCollector implements ServiceListener {
             for (final ServiceReference<?> serviceReference : context.getAllServiceReferences(null, null)) {
                 add(serviceReference);
             }
-        } catch (final InvalidSyntaxException e) {
+        } catch (InvalidSyntaxException e) {
             // Impossible, no filter specified.
         }
 
@@ -263,13 +263,29 @@ public class WebserviceCollector implements ServiceListener {
                         outInterceptors.add(index, new com.openexchange.soap.cxf.interceptor.XMLFaultOutInterceptor());
                     }
                 }
+                {
+                    final List<Interceptor<? extends Message>> inInterceptors = serverEndpoint.getInInterceptors();
+                    boolean found = false;
+                    int index = 0;
+                    for (final Interceptor<? extends Message> interceptor : inInterceptors) {
+                        if (interceptor instanceof org.apache.cxf.frontend.WSDLGetInterceptor) {
+                            found = true;
+                            break;
+                        }
+                        index++;
+                    }
+                    if (found) {
+                        inInterceptors.remove(index);
+                        inInterceptors.add(index, new com.openexchange.soap.cxf.interceptor.HttpsAwareWSDLGetInterceptor());
+                    }
+                }
                 // Add logging interceptors
                 serverEndpoint.getInInterceptors().add(new com.openexchange.soap.cxf.interceptor.LoggingInInterceptor());
                 serverEndpoint.getOutInterceptors().add(new com.openexchange.soap.cxf.interceptor.LoggingOutInterceptor());
             }
             oldEndpoint = endpoints.replace(name, endpoint);
             LOG.info("Publishing endpoint succeeded. Published \"{}\" under address \"{}\".", name, address);
-        } catch (final Throwable t) {
+        } catch (Throwable t) {
             ExceptionUtils.handleThrowable(t);
             LOG.error("Publishing endpoint failed. Couldn't publish \"{}\" under address \"{}\".", name, address, t);
             oldEndpoint = null;
@@ -283,7 +299,7 @@ public class WebserviceCollector implements ServiceListener {
         try {
             final Class<? extends Object> clazz = service.getClass();
             return (null == clazz) ? false : (null != clazz.getAnnotation(WebService.class));
-        } catch (final Exception e) {
+        } catch (Exception e) {
             return false;
         }
     }
